@@ -1,5 +1,5 @@
 from inspect import getfullargspec, isawaitable, ismethod
-from typing import TYPE_CHECKING, Any, Dict, List, Tuple, cast
+from typing import TYPE_CHECKING, Any, Dict, List, Set, Tuple, Type, Union, cast
 
 from starlette.routing import Router as StarletteRouter
 
@@ -11,8 +11,6 @@ from starlite.exceptions import (
 )
 
 if TYPE_CHECKING:
-    from typing import Set
-
     from starlette.types import ASGIApp, Receive, Scope, Send
 
     from starlite.app import Starlite
@@ -20,10 +18,18 @@ if TYPE_CHECKING:
     from starlite.types import LifeCycleHandler
 
 
+class PathParamPlaceholder:
+    """Sentinel object to represent a path param in the route map."""
+
+
+PathParamPlaceholderType = Type[PathParamPlaceholder]
+RouteMapNode = Dict[Union[str, PathParamPlaceholderType], Any]
+ComponentsSet = Set[Union[str, PathParamPlaceholderType]]
+
+
 class StarliteASGIRouter(StarletteRouter):
-    """
-    This class extends the Starlette Router class and *is* the ASGI app used in Starlite
-    """
+    """This class extends the Starlette Router class and *is* the ASGI app used
+    in Starlite."""
 
     def __init__(
         self,
@@ -34,9 +40,9 @@ class StarliteASGIRouter(StarletteRouter):
         self.app = app
         super().__init__(on_startup=on_startup, on_shutdown=on_shutdown)
 
-    def _traverse_route_map(self, path: str, scope: "Scope") -> Tuple[Dict[str, Any], List[str]]:
-        """
-        Traverses the application route mapping and retrieves the correct node for the request url.
+    def _traverse_route_map(self, path: str, scope: "Scope") -> Tuple[RouteMapNode, List[str]]:
+        """Traverses the application route mapping and retrieves the correct
+        node for the request url.
 
         Raises NotFoundException if no correlating node is found
         """
@@ -44,24 +50,24 @@ class StarliteASGIRouter(StarletteRouter):
         current_node = self.app.route_map
         components = ["/", *[component for component in path.split("/") if component]]
         for component in components:
-            components_set = cast("Set[str]", current_node["_components"])
+            components_set = cast("ComponentsSet", current_node["_components"])
             if component in components_set:
-                current_node = cast("Dict[str, Any]", current_node[component])
+                current_node = cast("RouteMapNode", current_node[component])
                 if "_static_path" in current_node:
                     self._handle_static_path(scope=scope, node=current_node)
                     break
                 continue
-            if "*" in components_set:
+            if PathParamPlaceholder in components_set:
                 path_params.append(component)
-                current_node = cast("Dict[str, Any]", current_node["*"])
+                current_node = cast("RouteMapNode", current_node[PathParamPlaceholder])
                 continue
             raise NotFoundException()
         return current_node, path_params
 
     @staticmethod
-    def _handle_static_path(scope: "Scope", node: Dict[str, Any]) -> None:
-        """
-        Normalize the static path and update scope so file resolution will work as expected.
+    def _handle_static_path(scope: "Scope", node: RouteMapNode) -> None:
+        """Normalize the static path and update scope so file resolution will
+        work as expected.
 
         Args:
             scope: Request Scope
@@ -69,7 +75,6 @@ class StarliteASGIRouter(StarletteRouter):
 
         Returns:
             None
-
         """
         static_path = cast("str", node["_static_path"])
         if static_path != "/" and scope["path"].startswith(static_path):
@@ -80,8 +85,7 @@ class StarliteASGIRouter(StarletteRouter):
     def _parse_path_parameters(
         path_parameter_definitions: List["PathParameterDefinition"], request_path_parameter_values: List[str]
     ) -> Dict[str, Any]:
-        """
-        Parses path parameters into their expected types
+        """Parses path parameters into their expected types.
 
         Args:
             path_parameter_definitions: A list of [PathParameterDefinition][starlite.route.base.PathParameterDefinition] instances
@@ -108,15 +112,14 @@ class StarliteASGIRouter(StarletteRouter):
             ) from e
 
     def _parse_scope_to_route(self, scope: "Scope") -> Tuple[Dict[str, "ASGIApp"], bool]:
-        """
-        Given a scope object, retrieve the _asgi_handlers and _is_asgi values from correct trie node.
-        """
+        """Given a scope object, retrieve the _asgi_handlers and _is_asgi
+        values from correct trie node."""
 
         path = cast("str", scope["path"]).strip()
         if path != "/" and path.endswith("/"):
             path = path.rstrip("/")
         if path in self.app.plain_routes:
-            current_node: Dict[str, Any] = self.app.route_map[path]
+            current_node: RouteMapNode = self.app.route_map[path]
             path_params: List[str] = []
         else:
             current_node, path_params = self._traverse_route_map(path=path, scope=scope)
@@ -135,9 +138,7 @@ class StarliteASGIRouter(StarletteRouter):
 
     @staticmethod
     def _resolve_asgi_app(scope: "Scope", asgi_handlers: Dict[str, "ASGIApp"], is_asgi: bool) -> "ASGIApp":
-        """
-        Given a scope, retrieves the correct ASGI App for the route
-        """
+        """Given a scope, retrieves the correct ASGI App for the route."""
         if is_asgi:
             return asgi_handlers[ScopeType.ASGI]
         if scope["type"] == ScopeType.HTTP:
@@ -147,9 +148,7 @@ class StarliteASGIRouter(StarletteRouter):
         return asgi_handlers[ScopeType.WEBSOCKET]
 
     async def __call__(self, scope: "Scope", receive: "Receive", send: "Send") -> None:
-        """
-        The main entry point to the Router class.
-        """
+        """The main entry point to the Router class."""
         try:
             asgi_handlers, is_asgi = self._parse_scope_to_route(scope=scope)
             asgi_handler = self._resolve_asgi_app(scope=scope, asgi_handlers=asgi_handlers, is_asgi=is_asgi)
@@ -158,9 +157,9 @@ class StarliteASGIRouter(StarletteRouter):
         await asgi_handler(scope, receive, send)
 
     async def _call_lifecycle_handler(self, handler: "LifeCycleHandler") -> None:
-        """
-        Determines whether the lifecycle handler expects an argument, and if so passes the `app.state` to it.
-        If the handler is an async function, it awaits the return.
+        """Determines whether the lifecycle handler expects an argument, and if
+        so passes the `app.state` to it. If the handler is an async function,
+        it awaits the return.
 
         Args:
             handler (LifeCycleHandler): sync or async callable that may or may not have an argument.
@@ -174,15 +173,11 @@ class StarliteASGIRouter(StarletteRouter):
             await value
 
     async def startup(self) -> None:
-        """
-        Run any `.on_startup` event handlers.
-        """
+        """Run any `.on_startup` event handlers."""
         for handler in self.on_startup:
             await self._call_lifecycle_handler(handler)
 
     async def shutdown(self) -> None:
-        """
-        Run any `.on_shutdown` event handlers.
-        """
+        """Run any `.on_shutdown` event handlers."""
         for handler in self.on_shutdown:
             await self._call_lifecycle_handler(handler)
