@@ -1,4 +1,4 @@
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Callable, Dict
 
 from orjson import OPT_INDENT_2, dumps
 
@@ -10,74 +10,187 @@ from starlite.handlers import get
 
 if TYPE_CHECKING:
     from pydantic_openapi_schema.v3_1_0.open_api import OpenAPI
+    from typing_extensions import Literal
 
 
 class OpenAPIController(Controller):
-    """Handlers for serving OpenAPI related interfaces."""
+    """Controller for OpenAPI endpoints."""
 
-    path = "/schema"
+    path: str = "/schema"
     """
-        All OpenAPI endpoints served under `/path`.
+        Base path for the OpenAPI documentation endpoints.
+    """
+    style: str = "body { margin: 0; padding: 0 }"
+    """
+    Base styling of the html body.
+    """
+    redoc_version: str = "next"
+    """
+    Redoc version to download from the CDN.
+    """
+    swagger_ui_version: str = "4.14.0"
+    """
+    SwaggerUI version to download from the CDN.
+    """
+    stoplight_elements_version: str = "7.6.5"
+    """
+    StopLight Elements version to download from the CDN.
+    """
+    favicon_url: str = ""
+    """
+    URL to download a favicon from.
     """
-    style = "body { margin: 0; padding: 0 }"
-    redoc_version = "next"
-    swagger_ui_version = "4.13.0"
-    stoplight_elements_version = "7.6.3"
-    favicon_url = ""
 
     # internal
-    _dumped_schema = ""
+    _dumped_schema: str = ""
     # until swagger-ui supports v3.1.* of OpenAPI officially, we need to modify the schema for it and keep it
     # separate from the redoc version of the schema, which is unmodified.
-    _dumped_modified_schema = ""
+    _dumped_modified_schema: str = ""
 
     @staticmethod
-    def schema_from_request(request: Request) -> "OpenAPI":
-        """Returns the openapi schema."""
+    def get_schema_from_request(request: Request) -> "OpenAPI":
+        """Returns the OpenAPI pydantic model from the request instance.
+
+        Args:
+            request: A [Starlite][starlite.connection.Request] instance.
+
+        Returns:
+            An [OpenAPI][pydantic_openapi_schema.v3_1_0.open_api.OpenAPI] instance.
+
+        Raises:
+            [ImproperlyConfiguredException][starlite.exceptions.ImproperlyConfiguredException]: If the application
+                `openapi_schema` attribute is `None`.
+        """
         if not request.app.openapi_schema:  # pragma: no cover
             raise ImproperlyConfiguredException("Starlite has not been instantiated with OpenAPIConfig")
         return request.app.openapi_schema
 
-    @get(path="/", media_type=MediaType.HTML, include_in_schema=False)
-    def root(self, request: Request) -> str:
-        """This route handler serves Redoc API documentation at the root path.
-
-        Override this handler to serve custom templates or other API
-        documentation, such as `render_swagger_ui`,
-        `render_stoplight_elements`, a template, or your own content.
+    @property
+    def favicon(self) -> str:
         """
-        return self.render_redoc(request)
+        Returns:
+            A link tag if self.favicon_url is not empty, otherwise returns a placeholder meta tag.
+        """
+        return f"<link rel='icon' type='image/x-icon' href='{self.favicon_url}'>" if self.favicon_url else "<meta/>"
+
+    @property
+    def render_methods_map(self) -> Dict["Literal['redoc', 'swagger', 'elements']", Callable[[Request], str]]:
+        """
+        Returns:
+            A mapping of string keys to render methods.
+        """
+        return {
+            "redoc": self.render_redoc,
+            "swagger": self.render_swagger_ui,
+            "elements": self.render_stoplight_elements,
+        }
 
     @get(path="/openapi.yaml", media_type=OpenAPIMediaType.OPENAPI_YAML, include_in_schema=False)
     def retrieve_schema_yaml(self, request: Request) -> "OpenAPI":
-        """Returns the openapi schema."""
-        return self.schema_from_request(request)
+        """Returns the OpenAPI schema as YAML with an
+        'application/vnd.oai.openapi' Content-Type header.
+
+        Args:
+            request:
+                A [Request][starlite.connection.Request] instance.
+
+        Returns:
+            A rendered YAML object..
+        """
+        return self.get_schema_from_request(request)
 
     @get(path="/openapi.json", media_type=OpenAPIMediaType.OPENAPI_JSON, include_in_schema=False)
     def retrieve_schema_json(self, request: Request) -> "OpenAPI":
-        """Returns the openapi schema."""
-        return self.schema_from_request(request)
+        """Returns the OpenAPI schema as JSON with an
+        'application/vnd.oai.openapi+json' Content-Type header.
 
-    @property
-    def favicon(self) -> str:
-        """Returns a link tag if self.favicon_url is not empty, otherwise
-        returns a placeholder meta tag."""
-        return f"<link rel='icon' type='image/x-icon' href='{self.favicon_url}'>" if self.favicon_url else "<meta/>"
+        Args:
+            request:
+                A [Request][starlite.connection.Request] instance.
+
+        Returns:
+            A rendered JSON object..
+        """
+        return self.get_schema_from_request(request)
+
+    @get(path="/", media_type=MediaType.HTML, include_in_schema=False)
+    def root(self, request: Request) -> str:
+        """The root route handler. Renders a static site based on the
+        'root_schema_site' value set in the application's.
+
+        [OpenAPIConfig][starlite.config.openapi.OpenAPIConfig]. Defaults to 'redoc'.
+
+        Args:
+            request:
+                A [Request][starlite.connection.Request] instance.
+
+        Returns:
+            A rendered html string.
+
+        Raises:
+            [ImproperlyConfiguredException][starlite.exceptions.ImproperlyConfiguredException]: If the application
+                `openapi_config` attribute is `None`.
+        """
+        config = request.app.openapi_config
+        if not config:  # pragma: no cover
+            raise ImproperlyConfiguredException("Starlite has not been instantiated with OpenAPIConfig")
+        method = self.render_methods_map[config.root_schema_site]
+        return method(request)
 
     @get(path="/swagger", media_type=MediaType.HTML, include_in_schema=False)
     def swagger_ui(self, request: Request) -> str:
-        """Endpoint that serves SwaggerUI."""
+        """Route handler responsible for rendering Swagger-UI.
+
+        Args:
+            request:
+                A [Request][starlite.connection.Request] instance.
+
+        Returns:
+            A rendered html string.
+        """
         return self.render_swagger_ui(request)
 
+    @get(path="/elements", media_type=MediaType.HTML, include_in_schema=False)
+    def stoplight_elements(self, request: Request) -> str:
+        """Route handler responsible for rendering StopLight Elements.
+
+        Args:
+            request:
+                A [Request][starlite.connection.Request] instance.
+
+        Returns:
+            A rendered html string.
+        """
+        return self.render_stoplight_elements(request)
+
+    @get(path="/redoc", media_type=MediaType.HTML, include_in_schema=False)
+    def redoc(self, request: Request) -> str:  # pragma: no cover
+        """Route handler responsible for rendering Redoc.
+
+        Args:
+            request:
+                A [Request][starlite.connection.Request] instance.
+
+        Returns:
+            A rendered html string.
+        """
+        return self.render_redoc(request)
+
     def render_swagger_ui(self, request: Request) -> str:
-        """Method that renders SwaggerUI from schema."""
-        schema = self.schema_from_request(request)
+        """This method renders an HTML page for Swagger-UI.
+
+        Notes:
+            - override this method to customize the template.
+
+        Args:
+            request:
+                A [Request][starlite.connection.Request] instance.
+
+        Returns:
+            A rendered html string.
+        """
+        schema = self.get_schema_from_request(request)
         # Note: Fix for Swagger rejection OpenAPI >=3.1
-        # We force the version to be lower to get the default JS bundle to accept it
-        # This works flawlessly as the main blocker for Swagger support for OpenAPI 3.1 is JSON schema support.
-        # Since we use the YAML format this is not an issue for us, and we can do this trick to get support right now.
-        # We use deepcopy to avoid changing the actual schema on the request. Since this is a cached call the effect is
-        # minimal.
         if self._dumped_modified_schema == "":
             schema_copy = schema.copy()
             schema_copy.openapi = "3.0.3"
@@ -122,14 +235,20 @@ class OpenAPIController(Controller):
             </html>
         """
 
-    @get(path="/elements/", media_type=MediaType.HTML, include_in_schema=False)
-    def stoplight_elements(self, request: Request) -> str:
-        """Endpoint that serves Stoplight Elements OpenAPI UI."""
-        return self.render_stoplight_elements(request)
-
     def render_stoplight_elements(self, request: Request) -> str:
-        """Method that renders Stoplight Elements OpenAPI UI from schema."""
-        schema = self.schema_from_request(request)
+        """This method renders an HTML page for StopLight Elements.
+
+        Notes:
+            - override this method to customize the template.
+
+        Args:
+            request:
+                A [Request][starlite.connection.Request] instance.
+
+        Returns:
+            A rendered html string.
+        """
+        schema = self.get_schema_from_request(request)
         head = f"""
           <head>
             <title>{schema.info.title}</title>
@@ -158,14 +277,20 @@ class OpenAPIController(Controller):
             </html>
         """
 
-    @get(path="/redoc", media_type=MediaType.HTML, include_in_schema=False)
-    def redoc(self, request: Request) -> str:  # pragma: no cover
-        """Endpoint that serves Redoc."""
-        return self.render_redoc(request)
-
     def render_redoc(self, request: Request) -> str:  # pragma: no cover
-        """Method that renders Redoc from schema."""
-        schema = self.schema_from_request(request)
+        """This method renders an HTML page for Redoc.
+
+        Notes:
+            - override this method to customize the template.
+
+        Args:
+            request:
+                A [Request][starlite.connection.Request] instance.
+
+        Returns:
+            A rendered html string.
+        """
+        schema = self.get_schema_from_request(request)
         if self._dumped_schema == "":
             self._dumped_schema = dumps(schema.json(by_alias=True, exclude_none=True), option=OPT_INDENT_2).decode(
                 "utf-8"
